//
//  MapViewController.m
//  FriendsMap
//
//  Created by Bernat Bombí Fernández on 15/11/11.
//  Copyright (c) 2011 . All rights reserved.
//

#import "AppDelegate.h"
#import "MapViewController.h"
#import "LoginViewController.h"
#import "ErrorViewController.h"
#import "YouViewController.h"
#import <MapKit/MapKit.h>
#import "Annotation.h"

@implementation MapViewController

@synthesize uid, mainStoryboard, mapView, locationManager, startingPoint, mapAnnotations, fid, mapCentered;


- (void)setPins{ //para cargar los pins
        
    
    //mientras cargo los nuevos pins, muestro un activity indicator
    CGRect frame = CGRectMake(0.0, 0.0, 25.0, 25.0);
    UIActivityIndicatorView *activityIndicator = [[UIActivityIndicatorView alloc]
                              initWithFrame:frame];
    [activityIndicator sizeToFit];
     activityIndicator.autoresizingMask =
    (UIViewAutoresizingFlexibleLeftMargin |
     UIViewAutoresizingFlexibleRightMargin |
     UIViewAutoresizingFlexibleTopMargin |
     UIViewAutoresizingFlexibleBottomMargin);
    
    UIBarButtonItem *loadingView = [[UIBarButtonItem alloc] 
                                    initWithCustomView:activityIndicator];
    
    self.navigationItem.rightBarButtonItem = loadingView;
    
    [activityIndicator startAnimating];
    
    //elimino los pins que hayan en el mapa
    NSMutableArray *toRemove = [NSMutableArray arrayWithCapacity:10];
    for (id annotation in mapView.annotations)
        if (annotation != mapView.userLocation)
            [toRemove addObject:annotation];
    [mapView removeAnnotations:toRemove];  
    
    //asincronamente pido al servidor los pins que debo mostrar, y los guarda en un NSDictionary
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
    
    NSMutableArray *locArray = [[NSMutableArray alloc] init];
        
    NSString *post =[NSString stringWithFormat:@"uid=%@",self.uid];
    NSString *hostStr = @"http://friendsmap.bombi.cat/php/plist/lista_loc.php?";
    hostStr = [hostStr stringByAppendingString:post];  
    NSURL *dataURL =  [NSURL URLWithString:hostStr];    
    NSDictionary *plistDict = [NSDictionary dictionaryWithContentsOfURL:dataURL];
    
    NSDictionary *LlistaDict = [plistDict valueForKey: @"Llista"];
    
    for (NSString *firstLevelString in LlistaDict){
        
        NSDictionary *LlistaContentsDict = [LlistaDict valueForKey:firstLevelString];
        
        NSString *tempName, *tempFid, *tempLon, *tempLat;
        CLLocationCoordinate2D tempCoordinate;
        
        for (NSString *secondLevelString in LlistaContentsDict){
            
            if ([secondLevelString isEqualToString:@"Name"])
                tempName = [LlistaContentsDict valueForKey:secondLevelString];
            else if ([secondLevelString isEqualToString:@"Id"])
                tempFid = [LlistaContentsDict valueForKey:secondLevelString];
            else if ([secondLevelString isEqualToString:@"Long"])
                tempLon = [LlistaContentsDict valueForKey:secondLevelString];
            else if ([secondLevelString isEqualToString:@"Lat"])
                tempLat = [LlistaContentsDict valueForKey:secondLevelString];             
        }
                
        tempCoordinate.latitude = [tempLat doubleValue];
        tempCoordinate.longitude = [tempLon doubleValue];
        
        //si el usuario existe... vaya, si se ha localizado alguna vez
        if(tempCoordinate.latitude != 0 && tempCoordinate.longitude != 0){

        Annotation *tempAnnotation = [[Annotation alloc] initWithTitle:tempName initWithFid:tempFid andCoordinate:tempCoordinate];
                    
        [locArray addObject:tempAnnotation];
            
        }
        
        
    }
        
    dispatch_sync(dispatch_get_main_queue(), ^{

    //añado los pins    
    [self.mapView addAnnotations:locArray];
        
        //una vez cargados los pins y añadidos, vuelvo a mostrar el boton de actualizar
        UIBarButtonItem *button = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh target:self action:@selector(setPins)];
        
        self.navigationItem.rightBarButtonItem = button;
         
         });
    });
}

- (void) viewDidAppear:(BOOL)animated{
    
    //compruebo la conexión a internet
    AppDelegate *appDelegate = [[UIApplication sharedApplication] delegate];
    
    if(![appDelegate reachable]){
        
        ErrorViewController *errorViewController = (ErrorViewController*)[mainStoryboard 
                                                                          instantiateViewControllerWithIdentifier: @"errorView"];
        [self presentModalViewController: errorViewController animated: YES ];
    }    
    
    LoginViewController *loginViewController = (LoginViewController*)[mainStoryboard 
                                                                      instantiateViewControllerWithIdentifier: @"loginView"];    
	NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    
    NSString *usuari = [defaults objectForKey:@"uid"];
        
    //si self.uid es diferente a usuario cambio el valor de self.uid a el de usuario, y llamo al metodo de setpins
    if(usuari != self.uid){        
                
        self.uid = usuari;
        
        [self setPins];
    }    
    if(uid == nil){
    [self presentModalViewController: loginViewController animated: NO ];
    }
    
} 

- (void) viewDidLoad{
    
    self.mapView.delegate = self;
    
    //dependiendo de el dispositivo selecciono un storyboard u otro
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPad" bundle: nil];
    }
    else {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle: nil];
    } 
    
    //defino self.uid
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    self.uid = [defaults objectForKey:@"uid"];
            
    self.navigationItem.title = @"Mapa"; 
    
    //mapa standard
    self.mapView.mapType = MKMapTypeStandard;
    
    //creo un botón que pongo en navigationItem.rightBarButtonitem, para poder recargar los pines en cualquier momento
    UIBarButtonItem *button = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh target:self action:@selector(setPins)];
    
    self.navigationItem.rightBarButtonItem = button;
    
    [self setPins];
    
    //centrar el mapa en la posicion del usuario
    [self.mapView.userLocation addObserver:self  
                                forKeyPath:@"location"  
                                   options:(NSKeyValueObservingOptionNew|NSKeyValueObservingOptionOld)  
                                   context:NULL];
    
    
}   

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - View lifecycle


- (void)viewDidUnload
{
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        return (interfaceOrientation == UIInterfaceOrientationLandscapeLeft);
    }
    else {
        return (interfaceOrientation == UIInterfaceOrientationPortrait);
    }
}

#pragma mark -
#pragma mark MKMapViewDelegate

- (MKAnnotationView *)mapView:(MKMapView *)mV viewForAnnotation:(id <MKAnnotation>)annotation
{
    MKPinAnnotationView *pinAnnotation = nil;
    if(annotation != mapView.userLocation) 
    {
        static NSString *defaultPinID = @"myPin";
        pinAnnotation = (MKPinAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:defaultPinID];
        if ( pinAnnotation == nil )
            pinAnnotation = [[MKPinAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:defaultPinID];
        
        pinAnnotation.canShowCallout = YES;
        
        //pongo el disclosure button a la burbuja
        UIButton *infoButton = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
        pinAnnotation.rightCalloutAccessoryView = infoButton;
        
    }
        
    return pinAnnotation;
}
- (void)mapView:(MKMapView *)mapView annotationView:(MKAnnotationView *)pin calloutAccessoryControlTapped:(UIControl *)control {
    YouViewController *youViewController = (YouViewController*)[mainStoryboard 
                                                                instantiateViewControllerWithIdentifier: @"youView"];
    
    //paso el numero de ID del amigo al nuevo controlador
    
    Annotation *theAnnotation = (Annotation *)pin.annotation;
        
    youViewController.fId = theAnnotation.fid;
    
    UIBarButtonItem *newBackButton = [[UIBarButtonItem alloc] initWithTitle: @"Atrás" style: UIBarButtonItemStyleBordered target: nil action: nil];    
    [[self navigationItem] setBackBarButtonItem: newBackButton];
    
    //me voy al nuevo controlador
    [self.navigationController pushViewController:youViewController animated:YES];
}

-(void)observeValueForKeyPath:(NSString *)keyPath  
                     ofObject:(id)object  
                       change:(NSDictionary *)change  
                      context:(void *)context {  
    
    //centro el mapa en el usuario
    
    if(self.mapView.userLocation.coordinate.longitude == 0 && self.mapView.userLocation.coordinate.latitude == 0){
        
        self.mapCentered = TRUE;
    }
    else{
    if(!mapCentered){
    MKCoordinateRegion region;
    region.center = self.mapView.userLocation.coordinate;  
    
    MKCoordinateSpan span; 
    span.latitudeDelta  = 0.09; // Change these values to change the zoom
    span.longitudeDelta = 0.09; 
    region.span = span;
    
        [self.mapView setRegion:region animated:YES];
        
        self.mapCentered = TRUE;
    }
    }
    
}


@end
