//
//  MeTableViewController.m
//  FriendsMap
//
//  Created by Bernat Bombí Fernández on 21/11/11.
//  Copyright (c) 2011 . All rights reserved.
//

#import "MeTableViewController.h"
#import "WebViewController.h"
#import "LoginViewController.h"
#import "FriendsListViewController.h"
#import "FriendsRequestsViewController.h"
#import "AppDelegate.h"
#import "ErrorViewController.h"

@implementation MeTableViewController

@synthesize tableView, uid, nomU, cityU, mailU, lastPath, mainStoryboard;

//view correspondiente al perfil de usuario

- (void) viewDidAppear:(BOOL)animated{
    AppDelegate *appDelegate = [[UIApplication sharedApplication] delegate];
    
    if(![appDelegate reachable]){
        
        ErrorViewController *errorViewController = (ErrorViewController*)[mainStoryboard 
                                                                          instantiateViewControllerWithIdentifier: @"errorView"];
        [self presentModalViewController: errorViewController animated: YES ];
    } 
}

- (void)viewWillAppear:(BOOL)animated
{    
    
    [super viewDidAppear:animated];
    
    [self.tableView deselectRowAtIndexPath:[self.tableView indexPathForSelectedRow] animated:YES];
    
    //si self.uid es diferente a los datos de usuario quiere decir que viene de un logout, y tiene que reiniciar los datos
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    
    if(self.uid != [defaults objectForKey:@"uid"]){
    self.uid = [defaults objectForKey:@"uid"];
    self.nomU = [defaults objectForKey:@"nom"];
    self.cityU = [defaults objectForKey:@"city"];
    self.mailU = [defaults objectForKey:@"mail"];
    
    //scroll to top
    [self.tableView scrollRectToVisible:CGRectMake(0, 0, 1, 1) animated:NO];
    [self.tableView reloadData];
    }
}

- (void)viewDidLoad{
    
    //elijo storyboard dependiendo del dispositivo
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPad" bundle: nil];
    }
    else {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle: nil];
    } 
    
    //on view did load, asigno valores a las variables
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
        self.uid = [defaults objectForKey:@"uid"];
        self.nomU = [defaults objectForKey:@"nom"];
        self.cityU = [defaults objectForKey:@"city"];
        self.mailU = [defaults objectForKey:@"mail"];
        
    self.navigationItem.title = @"Yo"; 
    
    // creo un botón que me servira para hacer el log out de usuario
    UIButton *btnDes = [UIButton buttonWithType:UIButtonTypeRoundedRect];
    [btnDes setTitle:@"Log out" forState:UIControlStateNormal];
    btnDes.backgroundColor = [UIColor clearColor];    
    UIImage* redButton = [UIImage imageNamed:@"red.png"]; 
    UIImage *newImage = [redButton stretchableImageWithLeftCapWidth:redButton.size.width/2 topCapHeight:redButton.size.height/2];
    [btnDes setBackgroundImage:newImage forState:UIControlStateNormal];
    [btnDes setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [btnDes addTarget:self action:@selector(logout:) forControlEvents:UIControlEventTouchUpInside];
    
    //lo añado en un footerView
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        btnDes.frame = CGRectMake(0, 0, 935, 40);
        UIView *footerView = [[UIView alloc] initWithFrame:CGRectMake(45, 0, 935, 60)];
        [footerView addSubview:btnDes];
        tableView.tableFooterView = footerView;
    }
    else {
        btnDes.frame = CGRectMake(0, 0, 300, 40);
        UIView *footerView = [[UIView alloc] initWithFrame:CGRectMake(10, 0, 300, 60)];
        [footerView addSubview:btnDes];       
        tableView.tableFooterView = footerView;
    }
    
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    
}

#pragma mark - Table view data source


 - (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 4;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    if(section == 0)return 2;
    else return 1;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{    
    
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [self.tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier];
    }
    
    //dependiendo del la row y section escribo un texto u otro
            
    if(indexPath.section == 0){
        if(indexPath.row == 0){
            cell.userInteractionEnabled = NO;
            cell.textLabel.text = cityU;
        }
        if(indexPath.row == 1){
            cell.textLabel.text = mailU;
        }
    }
    if(indexPath.section == 1){
        if(indexPath.row == 0){
            cell.textLabel.text = @"Lista de amistades";
        }
    }
    if(indexPath.section == 2){
        if(indexPath.row == 0){
            cell.textLabel.text = @"Modificar mis datos de usuario";
        }
    }
    if(indexPath.section == 3){
        if(indexPath.row == 0){
            cell.textLabel.text = @"Solicitudes de amistad";
        }
    }
    
    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section{
    
    if (section==0) {
        return nomU;
    } else {
        return nil;
    }
    
}

- (UITableViewCellAccessoryType)tableView:(UITableView *)tableView accessoryTypeForRowWithIndexPath:(NSIndexPath *)indexPath{
    
    if (indexPath.section == 0)
        if(indexPath.row == 0)
        return UITableViewCellAccessoryNone;
    
    return UITableViewCellAccessoryDisclosureIndicator;
}


#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    
    //si pulso el correo electrónico del usuario (section 0, row 1) abre la app de mail
    if(indexPath.section == 0)
        if(indexPath.row == 1)
        {
            NSString *path = [NSString stringWithFormat:@"mailto:%@", mailU];
            NSURL *url = [NSURL URLWithString:path];
            [[UIApplication sharedApplication] openURL:url];
            [self.tableView deselectRowAtIndexPath:indexPath animated:YES];
        }
        
    //si pulso en modificar datos, cargo el webviewcontroller, con la web para cambiar los datos de usuario
    if(indexPath.section == 2)
        if(indexPath.row == 0)
        {            
            
            WebViewController *detailViewController = (WebViewController*)[mainStoryboard 
                                                                              instantiateViewControllerWithIdentifier: @"webView"];
            NSString *changeDataUrl = [NSString stringWithFormat:@"http://friendsmap.bombi.cat/change_data.php?id=%@", uid];
            // paso los datos necesarios
            detailViewController.URL = [NSURL URLWithString:changeDataUrl];
            detailViewController.viewTitle = @"Modificar datos";
            UIBarButtonItem *newBackButton = [[UIBarButtonItem alloc] initWithTitle: @"Atrás" style: UIBarButtonItemStyleBordered target: nil action: nil];    
            [[self navigationItem] setBackBarButtonItem: newBackButton];
            [self.navigationController pushViewController:detailViewController animated:YES];
            
        }
    //si pulso en lista de amistades, cargo el view correspondiente
    if(indexPath.section == 1)
        if(indexPath.row == 0)
        {            
            
            FriendsListViewController *friendsListViewController = (FriendsListViewController*)[mainStoryboard 
                                                                           instantiateViewControllerWithIdentifier: @"friendsView"];
            // paso mi uid (user id).
            friendsListViewController.uid = self.uid;
            UIBarButtonItem *newBackButton = [[UIBarButtonItem alloc] initWithTitle: @"Atrás" style: UIBarButtonItemStyleBordered target: nil action: nil];    
            [[self navigationItem] setBackBarButtonItem: newBackButton];
            [self.navigationController pushViewController:friendsListViewController animated:YES];
            
        }
    //si pulso en solicitudes de amistad voy hacia el view correspondiente
    if(indexPath.section == 3){
        if(indexPath.row == 0){            
            
            FriendsRequestsViewController *friendsRequestsViewController = (FriendsRequestsViewController*)[mainStoryboard 
            instantiateViewControllerWithIdentifier: @"requestsView"];
            //paso uid
            friendsRequestsViewController.uid = self.uid;
            UIBarButtonItem *newBackButton = [[UIBarButtonItem alloc] initWithTitle: @"Atrás" style: UIBarButtonItemStyleBordered target: nil action: nil];    
            [[self navigationItem] setBackBarButtonItem: newBackButton];
            [self.navigationController pushViewController:friendsRequestsViewController animated:YES];
        }
    }
     //descelecciona la fila
    lastPath = indexPath;
    
}

-(IBAction)logout:(id)sender{
    
    //si pulso el botón de Logout reinicio userdefaults y cargo el loginviewcontroller
    
    [NSUserDefaults resetStandardUserDefaults];
    
    NSString *appDomain = [[NSBundle mainBundle] bundleIdentifier];
    [[NSUserDefaults standardUserDefaults] removePersistentDomainForName:appDomain];    
    
    LoginViewController *loginViewController = (LoginViewController*)[mainStoryboard 
                                                                      instantiateViewControllerWithIdentifier: @"loginView"]; 
    
    [self presentModalViewController: loginViewController animated: YES ];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{    
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        return (interfaceOrientation == UIInterfaceOrientationLandscapeLeft);
    }
    else {
        return (interfaceOrientation == UIInterfaceOrientationPortrait);
    }
}

@end
