//
//  DetailMapViewController.m
//  FriendsMap
//
//  Created by Bernat Bombí Fernández on 26/12/11.
//  Copyright (c) 2011 . All rights reserved.
//

#import "DetailMapViewController.h"
#import "AppDelegate.h"
#import "ErrorViewController.h"
#import <MapKit/MapKit.h>
#import "Annotation.h"

@implementation DetailMapViewController

@synthesize mainStoryboard, mapView, locationManager, startingPoint, mapAnnotations, fid, mapCentered, tempCoordinate;


- (void)setPins{//para poner el pin en el mapa
    
    //mientras cargo el pin, muestro un activity indicator
    CGRect frame = CGRectMake(0.0, 0.0, 25.0, 25.0);
    UIActivityIndicatorView *activityIndicator = [[UIActivityIndicatorView alloc]
                                                  initWithFrame:frame];
    [activityIndicator sizeToFit];
    activityIndicator.autoresizingMask =
    (UIViewAutoresizingFlexibleLeftMargin |
     UIViewAutoresizingFlexibleRightMargin |
     UIViewAutoresizingFlexibleTopMargin |
     UIViewAutoresizingFlexibleBottomMargin);
    
    UIBarButtonItem *loadingView = [[UIBarButtonItem alloc] 
                                    initWithCustomView:activityIndicator];
    
    self.navigationItem.rightBarButtonItem = loadingView;
    
    [activityIndicator startAnimating];
    
    //elimino los pins que haya
    NSMutableArray *toRemove = [NSMutableArray arrayWithCapacity:10];
    for (id annotation in mapView.annotations)
        if (annotation != mapView.userLocation)
            [toRemove addObject:annotation];
    [mapView removeAnnotations:toRemove];  
    
    //asincronamente busco el pin, y una vez cargado en el NSDictionary lo cargo en el mapa
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
        
        NSMutableArray *locArray = [[NSMutableArray alloc] init];
        
        NSString *post =[NSString stringWithFormat:@"fid=%@",self.fid];
        NSString *hostStr = @"http://friendsmap.bombi.cat/php/plist/lista_lastPos.php?";
        hostStr = [hostStr stringByAppendingString:post];  
        NSURL *dataURL =  [NSURL URLWithString:hostStr];    
        NSDictionary *plistDict = [NSDictionary dictionaryWithContentsOfURL:dataURL];
        
        NSDictionary *LlistaDict = [plistDict valueForKey: @"Llista"];
        
        for (NSString *firstLevelString in LlistaDict){
            
            NSDictionary *LlistaContentsDict = [LlistaDict valueForKey:firstLevelString];
            
            NSString *tempName, *tempFid, *tempLon, *tempLat;
            
            for (NSString *secondLevelString in LlistaContentsDict){
                
                if ([secondLevelString isEqualToString:@"Name"])
                    tempName = [LlistaContentsDict valueForKey:secondLevelString];
                else if ([secondLevelString isEqualToString:@"Id"])
                    tempFid = [LlistaContentsDict valueForKey:secondLevelString];
                else if ([secondLevelString isEqualToString:@"Long"])
                    tempLon = [LlistaContentsDict valueForKey:secondLevelString];
                else if ([secondLevelString isEqualToString:@"Lat"])
                    tempLat = [LlistaContentsDict valueForKey:secondLevelString];             
            }
            
            tempCoordinate.latitude = [tempLat doubleValue];
            tempCoordinate.longitude = [tempLon doubleValue];
            
            //si el usuario existe... vaya, si se ha localizado alguna vez
            if(tempCoordinate.latitude != 0 && tempCoordinate.longitude != 0){
                
            Annotation *tempAnnotation = [[Annotation alloc] initWithTitle:tempName initWithFid:tempFid andCoordinate:self.tempCoordinate];
                        
            [locArray addObject:tempAnnotation];
                
            }
            
            
        }
        
        dispatch_sync(dispatch_get_main_queue(), ^{
            
            //añado las anotaciones, animo el mapa hasta la posicion
            if([locArray count] != 0){
            [self.mapView addAnnotations:locArray];
            
            MKCoordinateRegion region;
            region.center = self.tempCoordinate;
            
            MKCoordinateSpan span; 
            span.latitudeDelta  = 0.09; // Change these values to change the zoom
            span.longitudeDelta = 0.09; 
            region.span = span;
            
            [self.mapView setRegion:region animated:YES];
            }
            else{
                [self.mapView isHidden];
                //si el usuario nunca se ha geolocalizado muestro una alerta
                UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ups!" message:@"El usuario nunca se ha geolocalizado" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil];
                [alert show];
            }
            
            self.navigationItem.rightBarButtonItem = nil;
            //elimino el activityindicator
            [activityIndicator stopAnimating];
            
        });
    });
}

- (void) viewDidAppear:(BOOL)animated{
    
    AppDelegate *appDelegate = [[UIApplication sharedApplication] delegate];
    
    if(![appDelegate reachable]){
        
        ErrorViewController *errorViewController = (ErrorViewController*)[mainStoryboard 
                                                                          instantiateViewControllerWithIdentifier: @"errorView"];
        [self presentModalViewController: errorViewController animated: YES ];
    }        
    
    self.fid = fid;
} 

- (void) viewDidLoad{
    
    self.mapView.delegate = self;
    
    //dependiendo del dispositivo elijo un stroyboard o otro
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPad" bundle: nil];
    }
    else {
        self.mainStoryboard = [UIStoryboard storyboardWithName:@"MainStoryboard_iPhone" bundle: nil];
    } 
    
    self.navigationItem.title = @"Posición"; 
    
    self.mapView.mapType = MKMapTypeStandard;
    
    //llamo al metodo setPins para poner el pin correcto
    [self setPins];
    
    
}   

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - View lifecycle


- (void)viewDidUnload
{
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        return (interfaceOrientation == UIInterfaceOrientationLandscapeLeft);
    }
    else {
        return (interfaceOrientation == UIInterfaceOrientationPortrait);
    }
}


@end
